@@ -33,6 +33,10 @@ class IdGenerator:
 gen_id = IdGenerator()
 
 
+def gen_uuid():
+    return str(uuid4())
+
+
 class QottoAuthTestApi(QottoAuthApi):
 
     def __init__(self):
@@ -152,9 +156,17 @@ class QottoAuthTestApi(QottoAuthApi):
         self._permissions[permission.permission_id] = permission
         return dict(permission=self.permission(permission.permission_id))
 
-    def user(self, id):
+    def user(self, id=None, uuid=None):
+        if not id and not uuid:
+            raise ValueError("Either id or uuid must be provided")
+        if not id:
+            for user in self._users.values():
+                if user.uuid == uuid:
+                    id = user.user_id
+                    break
         return dict(
             id=self._users[id].user_id,
+            uuid=self._users[id].uuid,
             name=self._users[id].name,
             isSuperuser=self._users[id].is_superuser,
             accounts=[
@@ -163,6 +175,7 @@ class QottoAuthTestApi(QottoAuthApi):
                     application=self.application(user_account.application.application_id),
                     user=dict(
                         id=self._users[id].user_id,
+                        uuid=self._users[id].uuid,
                         name=self._users[id].name,
                         isSuperuser=self._users[id].is_superuser,
                     ),
@@ -185,7 +198,7 @@ class QottoAuthTestApi(QottoAuthApi):
         return [self.user(id) for id in self._users]
 
     def createUser(self, name):
-        user = User(gen_id(), name, False)
+        user = User(gen_id(), name, gen_uuid(), False)
         self._users[user.user_id] = user
         self._user_cookies[user.user_id] = (str(uuid4()), str(uuid4()))
         return dict(user=self.user(user.user_id))
@@ -193,7 +206,7 @@ class QottoAuthTestApi(QottoAuthApi):
     def createUserFromIdentity(self, identityId):
         if identityId not in self._identities:
             raise ValueError(f"Unknown identity {identityId}")
-        user = User(gen_id(), self._identities[identityId].name, False)
+        user = User(gen_id(), self._identities[identityId].name, gen_uuid(), False)
         self._users[user.user_id] = user
         return dict(user=self.user(user.user_id))
 
