@@ -2,10 +2,12 @@
 
 from __future__ import annotations
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from enum import Enum
 from typing import Union, Optional
 
+from dataclasses_json import dataclass_json, config
+
 __all__ = [
     'Namespace',
     'Matching',
@@ -135,6 +137,7 @@ class Namespace:
         return self.path
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class Application:
     application_id: str
@@ -142,6 +145,7 @@ class Application:
     description: str
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class Permission:
     application: Application
@@ -150,13 +154,21 @@ class Permission:
     description: str
 
 
+@dataclass_json()
 @dataclass(frozen=True)
 class Organization:
     organization_id: str
     name: str
-    namespace: Namespace
+    namespace: Namespace = field(
+        metadata=config(
+            field_name='namespace',
+            encoder=str,
+            decoder=Namespace,
+        )
+    )
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class Authorization:
     authorization_id: str
@@ -167,6 +179,7 @@ class Authorization:
     matching: Matching
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class Role:
     role_id: str
@@ -176,6 +189,7 @@ class Role:
     inheritance: bool
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class Identity:
     identity_id: str
@@ -186,13 +200,16 @@ class Identity:
     blocked: bool
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class User:
     user_id: str
     name: str
+    uuid: str
     is_superuser: bool
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class Member:
     member_id: str
@@ -200,6 +217,7 @@ class Member:
     organization: Organization
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class Account:
     account_id: str
@@ -209,6 +227,7 @@ class Account:
     data: dict
 
 
+@dataclass_json
 @dataclass(frozen=True)
 class Cookie:
     name: str
