@@ -60,6 +60,7 @@ class QottoAuthService:
                 id
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -77,6 +78,7 @@ class QottoAuthService:
                 account_id=account_data['id'],
                 user=User(
                     user_id=account_data['user']['id'],
+                    uuid=account_data['user']['uuid'],
                     name=account_data['user']['name'],
                     is_superuser=account_data['user']['isSuperuser'],
                 ),
@@ -91,7 +93,7 @@ class QottoAuthService:
             for account_data in accounts_data
         ]
 
-    def get_account(self, account_id: str) -> Optional[Account]:
+    def get_account(self, account_id: str) -> Account:
         account_data = self.api.query(
             name='account',
             variables=[
@@ -101,6 +103,7 @@ class QottoAuthService:
                 id
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -113,12 +116,11 @@ class QottoAuthService:
                 data
             ''',
         )
-        if not account_data:
-            return None
         return Account(
             account_id=account_data['id'],
             user=User(
                 user_id=account_data['user']['id'],
+                uuid=account_data['user']['uuid'],
                 name=account_data['user']['name'],
                 is_superuser=account_data['user']['isSuperuser'],
             ),
@@ -148,7 +150,7 @@ class QottoAuthService:
             ) for organization_data in organizations_data
         ]
 
-    def get_organization(self, organization_id: str) -> Optional[Organization]:
+    def get_organization(self, organization_id: str) -> Organization:
         organization_data = self.api.query(
             name='organization',
             variables=[
@@ -160,8 +162,6 @@ class QottoAuthService:
                 namespace
             ''',
         )
-        if not organization_data:
-            return None
         return Organization(
             organization_id=organization_data['id'],
             name=organization_data['name'],
@@ -203,7 +203,7 @@ class QottoAuthService:
             ) for application_data in applications_data
         ]
 
-    def get_application(self, application_id: str) -> Optional[Application]:
+    def get_application(self, application_id: str) -> Application:
         application_data = self.api.query(
             name='application',
             variables=[
@@ -215,8 +215,6 @@ class QottoAuthService:
                 description
             ''',
         )
-        if not application_data:
-            return None
         return Application(
             application_id=application_data['id'],
             name=application_data['name'],
@@ -262,7 +260,7 @@ class QottoAuthService:
             ) for permission_data in permissions_data
         ]
 
-    def get_permission(self, permission_id: str) -> Optional[Permission]:
+    def get_permission(self, permission_id: str) -> Permission:
         permission_data = self.api.query(
             name='permission',
             variables=[
@@ -279,8 +277,6 @@ class QottoAuthService:
                 }
             ''',
         )
-        if not permission_data:
-            return None
         return Permission(
             permission_id=permission_data['id'],
             name=permission_data['name'],
@@ -303,6 +299,7 @@ class QottoAuthService:
                 blocked
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -317,13 +314,14 @@ class QottoAuthService:
                 blocked=identity_data['blocked'],
                 user=User(
                     user_id=identity_data['user']['id'],
+                    uuid=identity_data['user']['uuid'],
                     name=identity_data['user']['name'],
                     is_superuser=identity_data['user']['isSuperuser'],
                 ) if identity_data.get('user') else None,
             ) for identity_data in identities_data
         ]
 
-    def get_identity(self, identity_id: str) -> Optional[Identity]:
+    def get_identity(self, identity_id: str) -> Identity:
         identity_data = self.api.query(
             name='identity',
             variables=[
@@ -337,13 +335,12 @@ class QottoAuthService:
                 blocked
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
             ''',
         )
-        if not identity_data:
-            return None
         return Identity(
             identity_id=identity_data['id'],
             name=identity_data['name'],
@@ -352,6 +349,7 @@ class QottoAuthService:
             blocked=identity_data['blocked'],
             user=User(
                 user_id=identity_data['user']['id'],
+                uuid=identity_data['user']['uuid'],
                 name=identity_data['user']['name'],
                 is_superuser=identity_data['user']['isSuperuser'],
             ) if identity_data.get('user') else None,
@@ -376,6 +374,7 @@ class QottoAuthService:
                 blocked
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -389,6 +388,7 @@ class QottoAuthService:
             blocked=identity_data['blocked'],
             user=User(
                 user_id=identity_data['user']['id'],
+                uuid=identity_data['user']['uuid'],
                 name=identity_data['user']['name'],
                 is_superuser=identity_data['user']['isSuperuser'],
             ) if identity_data.get('user') else None,
@@ -399,6 +399,7 @@ class QottoAuthService:
             name='users',
             body='''
                 id
+                uuid
                 name
                 isSuperuser
             ''',
@@ -406,27 +407,29 @@ class QottoAuthService:
         return [
             User(
                 user_id=user_data['id'],
+                uuid=user_data['uuid'],
                 name=user_data['name'],
                 is_superuser=user_data['isSuperuser'],
             ) for user_data in users_data
         ]
 
-    def get_user(self, user_id: str) -> Optional[User]:
+    def get_user(self, user_id: str = None, user_uuid: str = None) -> User:
         user_data = self.api.query(
             name='user',
             variables=[
-                ('id', 'ID!', user_id),
+                ('id', 'ID', user_id),
+                ('uuid', 'UUID', user_uuid),
             ],
             body='''
                 id
+                uuid
                 name
                 isSuperuser
             ''',
         )
-        if not user_data:
-            return None
         return User(
             user_id=user_data['id'],
+            uuid=user_data['uuid'],
             name=user_data['name'],
             is_superuser=user_data['isSuperuser'],
         )
@@ -446,6 +449,7 @@ class QottoAuthService:
             ],
             body="""
                 id
+                uuid
                 name
                 isSuperuser
             """,
@@ -454,6 +458,7 @@ class QottoAuthService:
             return None
         return User(
             user_id=user_data['id'],
+            uuid=user_data['uuid'],
             name=user_data['name'],
             is_superuser=user_data['isSuperuser'],
         )
@@ -502,6 +507,7 @@ class QottoAuthService:
                 id
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -520,6 +526,7 @@ class QottoAuthService:
                 account_id=account_data['id'],
                 user=User(
                     user_id=account_data['user']['id'],
+                    uuid=account_data['user']['uuid'],
                     name=account_data['user']['name'],
                     is_superuser=account_data['user']['isSuperuser'],
                 ),
@@ -547,6 +554,7 @@ class QottoAuthService:
                 id
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -562,6 +570,7 @@ class QottoAuthService:
                 member_id=member_data['id'],
                 user=User(
                     user_id=member_data['user']['id'],
+                    uuid=member_data['user']['uuid'],
                     name=member_data['user']['name'],
                     is_superuser=member_data['user']['isSuperuser'],
                 ),
@@ -573,7 +582,7 @@ class QottoAuthService:
             ) for member_data in members_data
         ]
 
-    def get_member(self, member_id: str) -> Optional[Member]:
+    def get_member(self, member_id: str) -> Member:
         member_data = self.api.query(
             name='member',
             variables=[
@@ -583,6 +592,7 @@ class QottoAuthService:
                 id
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -593,12 +603,11 @@ class QottoAuthService:
                 }
             ''',
         )
-        if not member_data:
-            return None
         return Member(
             member_id=member_data['id'],
             user=User(
                 user_id=member_data['user']['id'],
+                uuid=member_data['user']['uuid'],
                 name=member_data['user']['name'],
                 is_superuser=member_data['user']['isSuperuser'],
             ),
@@ -631,6 +640,7 @@ class QottoAuthService:
                 }
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -649,6 +659,7 @@ class QottoAuthService:
             ),
             user=User(
                 user_id=user_data['id'],
+                uuid=user_data['uuid'],
                 name=user_data['name'],
                 is_superuser=user_data['isSuperuser'],
             ),
@@ -759,7 +770,7 @@ class QottoAuthService:
             ) for authorization_data in authorizations_data
         ]
 
-    def get_authorization(self, authorization_id: str) -> Optional[Authorization]:
+    def get_authorization(self, authorization_id: str) -> Authorization:
         authorization_data = self.api.query(
             name='authorization',
             variables=[
@@ -778,8 +789,6 @@ class QottoAuthService:
                 matching
             ''',
         )
-        if not authorization_data:
-            return None
         return Authorization(
             authorization_id=authorization_data['id'],
             name=authorization_data['name'],
@@ -856,7 +865,7 @@ class QottoAuthService:
             ) for role_data in roles_data
         ]
 
-    def get_role(self, role_id: str) -> Optional[Role]:
+    def get_role(self, role_id: str) -> Role:
         role_data = self.api.query(
             name='role',
             variables=[
@@ -874,8 +883,6 @@ class QottoAuthService:
                 inheritance
             ''',
         )
-        if not role_data:
-            return None
         return Role(
             role_id=role_data['id'],
             name=role_data['name'],
@@ -1116,6 +1123,7 @@ class QottoAuthService:
                 id
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -1134,6 +1142,7 @@ class QottoAuthService:
             account_id=account_data['id'],
             user=User(
                 user_id=account_data['user']['id'],
+                uuid=account_data['user']['uuid'],
                 name=account_data['user']['name'],
                 is_superuser=account_data['user']['isSuperuser'],
             ),
@@ -1158,6 +1167,7 @@ class QottoAuthService:
                 id
                 user {
                     id
+                    uuid
                     name
                     isSuperuser
                 }
@@ -1176,6 +1186,7 @@ class QottoAuthService:
             account_id=account_data['id'],
             user=User(
                 user_id=account_data['user']['id'],
+                uuid=account_data['user']['uuid'],
                 name=account_data['user']['name'],
                 is_superuser=account_data['user']['isSuperuser'],
             ),
@@ -1250,6 +1261,7 @@ class QottoAuthService:
             body='''
             user {
                 id
+                uuid
                 name
                 isSuperuser
             }
@@ -1258,6 +1270,7 @@ class QottoAuthService:
 
         return User(
             user_id=user_data['id'],
+            uuid=user_data['uuid'],
             name=user_data['name'],
             is_superuser=user_data['isSuperuser'],
         )
@@ -1274,6 +1287,7 @@ class QottoAuthService:
             body='''
             user {
                 id
+                uuid
                 name
                 isSuperuser
             }
@@ -1282,6 +1296,7 @@ class QottoAuthService:
 
         return User(
             user_id=user_data['id'],
+            uuid=user_data['uuid'],
             name=user_data['name'],
             is_superuser=user_data['isSuperuser'],
         )
@@ -1315,6 +1330,7 @@ class QottoAuthService:
             body='''
             user {
                 id
+                uuid
                 name
                 isSuperuser
             }
@@ -1323,6 +1339,7 @@ class QottoAuthService:
 
         return User(
             user_id=user_data['id'],
+            uuid=user_data['uuid'],
             name=user_data['name'],
             is_superuser=user_data['isSuperuser'],
         )
